==> deepin-image-viewer_5.7.4.orig.tar.xz: deepin-image-viewer-5.7.4/src/translations/deepin-image-viewer_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Afbeeldingen is een programma om afbeeldingen te tonen. Het heeft een stijlvol uiterlijk en vloeiende prestaties.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Bestandsinformatie</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Eigenschappen</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Dit bestand bevat meerdere pagina&apos;s. Gebruik Evince om alle pagina&apos;s te bekijken.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Map openen</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Je bent niet gemachtigd om deze afbeelding te bekijken</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Afbeelding niet aangetroffen</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Bewerkt op</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Afmetingen</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Gefotografeerd op</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Belichtingsmodus</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Belichtingsprogramma</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Belichtingstijd</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flits</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diafragma-opening</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brandpuntsafstand</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max. diafragma-opening</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Meetmethode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Witbalans</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flitscompensatie</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lensmodel</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Kleurruimte</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Cameramodel</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Afmetingen</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Label</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Niet aanpassen</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Pagina aanpassen aan afbeelding</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Afbeelding aanpassen aan pagina</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Aanpassen aan:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inch</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Afbeeldingspositie</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Aanpassing</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Afbeeldingsinstellingen</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Afbeeldingsinstellingen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Rolgordijn</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Wisselaar</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Schuiven</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Ring</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>yyyy/MM/dd HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Oké</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Voer een nieuwe naam in</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Kies een map</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Deze map wordt niet gesynchroniseerd</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Map toevoegen</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Mapsynchronisatie beheren</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>De mappenlijst is leeg</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Synchronisatie afbreken</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Het apparaat is afgekoppeld</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Deze map bestaat niet meer</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Bezig met berekenen...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Afbeelding bekijken</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Beeldvullend</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diavoorstelling beëindigen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Verwijderen uit album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als achtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Vorig scherm</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Volgend scherm</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Beeldvullende modus afsluiten</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Druk op een nieuwe sneltoets</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Afbeelding bekijken</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Standaardwaarden herstellen</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Beeldvullend</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diavoorstelling beëindigen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Verwijderen uit album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als achtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauzeren</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Afspelen</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diavoorstellingsinstellingen</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Overgangseffect</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Overgangsduur</translation>
    </message>
    <message>
        <source>second</source>
        <translation>seconde</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Mijn favorieten</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Grootte 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Aanpassen aan venster</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Terug</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Afbeeldingsbeheer</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mijn favorieten</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Grootte 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Aanpassen aan venster</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Geen afbeeldingen aangetroffen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Afbeelding niet aangetroffen</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Diavoorstellingsinstellingen</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Effect</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duur</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Sneltoetsen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Bekijken</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nieuw album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Tijdlijn</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Toevoegen aan album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Toevoegen aan nieuw album</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Beeldvullende modus afsluiten</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Beeldvullend</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Afdrukken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Verwijderen uit album</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Toev. aan favorieten</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Verw. uit favorieten</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigatievenster tonen</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigatievenster verbergen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als achtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Alle afbeeldingen</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Tekenen</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Afbeelding niet aangetroffen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Afbeelding openen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Afbeelding bekijken</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Beeldvullend</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Beeldvullende modus afsluiten</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Tekst extraheren</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diavoorstelling</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Naam wijzigen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiëren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Naar rechts draaien</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Naar links draaien</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Instellen als achtergrond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Tonen in bestandsbeheerder</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorige</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Volgende</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Inzoomen</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Uitzoomen</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Sneltoetsen tonen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Afbeeldingen is een programma om afbeeldingen te tonen met een stijlvolle vormgeving en vloeiende prestaties.</translation>
    </message>
</context>
</TS>
